==> Excavar-21.9.5-sources.jar: de/melanx/excavar/EventListener.java <==
package de.melanx.excavar;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import de.melanx.excavar.api.Excavador;
import de.melanx.excavar.api.PlayerHandler;
import de.melanx.excavar.api.events.DiggingEvent;
import de.melanx.excavar.api.shape.Shapes;
import de.melanx.excavar.client.HiddenRenderTypes;
import de.melanx.excavar.config.ListHandler;
import net.minecraft.core.Direction;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.server.level.ServerLevel;
import net.minecraft.server.level.ServerPlayer;
import net.minecraft.world.entity.item.ItemEntity;
import net.minecraft.world.level.block.state.BlockState;
import net.minecraft.world.phys.BlockHitResult;
import net.neoforged.bus.api.SubscribeEvent;
import net.neoforged.fml.common.EventBusSubscriber;
import net.neoforged.neoforge.client.event.RegisterRenderPipelinesEvent;
import net.neoforged.neoforge.common.NeoForge;
import net.neoforged.neoforge.event.level.BlockDropsEvent;
import net.neoforged.neoforge.event.level.BlockEvent;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

@EventBusSubscriber(modid = Excavar.MODID)
public class EventListener {

    public static Map<UUID, List<ItemEntity>> ITEMS_FOR_PLAYER = Maps.newHashMap();

    @SubscribeEvent
    public static void onBreakBlock(BlockEvent.BreakEvent event) {
        if (event.getPlayer() instanceof ServerPlayer player) {
            PlayerHandler playerHandler = Excavar.getPlayerHandler();
            UUID playerId = player.getGameProfile().id();
            if (playerHandler.canDig(player)) {
                BlockState state = event.getState();
                if (!ShapeUtil.miningAllowed(state) || !ListHandler.isToolAllowed(player.getMainHandItem())) {
                    return;
                }

                ServerLevel level = player.level();
                if (NeoForge.EVENT_BUS.post(new DiggingEvent.Pre(level, player, Lists.newArrayList(), state.getBlock())).isCanceled()) {
                    return;
                }

                Direction side = ((BlockHitResult) player.pick(20, 0, false)).getDirection();

                ResourceLocation shapeId = playerHandler.getShapeId(playerId);
                if (!ConfigHandler.allowShapeSelection.get() || Shapes.SHAPELESS.equals(shapeId)) {
                    shapeId = ShapeUtil.getShapeId(state.getBlock());
                }

                Excavador excavador = new Excavador(shapeId, event.getPos(), level, player, side, state);
                excavador.findBlocks();

                if (NeoForge.EVENT_BUS.post(new DiggingEvent.FoundPositions(level, player, excavador.getBlocksToMine(), state.getBlock())).isCanceled()) {
                    playerHandler.stopDigging(playerId);
                    return;
                }

                playerHandler.startDigging(playerId);
                excavador.mine(event.getPlayer().getMainHandItem());
                playerHandler.stopDigging(playerId);

                if (ITEMS_FOR_PLAYER.containsKey(playerId)) {
                    ITEMS_FOR_PLAYER.get(playerId).forEach(e -> {
                        e.setPos(event.getPos().getX(), event.getPos().getY(), event.getPos().getZ());
                        level.addFreshEntity(e);
                    });
                    ITEMS_FOR_PLAYER.remove(playerId);
                }

                NeoForge.EVENT_BUS.post(new DiggingEvent.Post(level, player, excavador.getBlocksToMine(), state.getBlock()));
            }
        }
    }

    @SubscribeEvent
    public static void captureDrops(BlockDropsEvent event) {
        if (!ConfigHandler.collectDrops.get()) {
            return;
        }

        if (event.isCanceled()) {
            return;
        }

        if (event.getBreaker() instanceof ServerPlayer player && Excavar.getPlayerHandler().isDigging(player.getGameProfile().id())) {
            event.setCanceled(true);
            ITEMS_FOR_PLAYER.computeIfAbsent(player.getGameProfile().id(), id -> new ArrayList<>()).addAll(event.getDrops());
        }
    }

    @SubscribeEvent
    public static void register(RegisterRenderPipelinesEvent event) {
        event.registerPipeline(HiddenRenderTypes.HIDDEN_RENDER_PIPELINE);
    }
}

==> Excavar-21.11.0-sources.jar: de/melanx/excavar/EventListener.java <==
package de.melanx.excavar;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import de.melanx.excavar.api.Excavador;
import de.melanx.excavar.api.PlayerHandler;
import de.melanx.excavar.api.events.DiggingEvent;
import de.melanx.excavar.api.shape.Shapes;
import de.melanx.excavar.client.HiddenRenderTypes;
import de.melanx.excavar.config.ListHandler;
import net.minecraft.core.Direction;
import net.minecraft.resources.Identifier;
import net.minecraft.server.level.ServerLevel;
import net.minecraft.server.level.ServerPlayer;
import net.minecraft.world.entity.item.ItemEntity;
import net.minecraft.world.level.block.state.BlockState;
import net.minecraft.world.phys.BlockHitResult;
import net.neoforged.bus.api.SubscribeEvent;
import net.neoforged.fml.common.EventBusSubscriber;
import net.neoforged.neoforge.client.event.RegisterRenderPipelinesEvent;
import net.neoforged.neoforge.common.NeoForge;
import net.neoforged.neoforge.event.level.BlockDropsEvent;
import net.neoforged.neoforge.event.level.BlockEvent;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

@EventBusSubscriber(modid = Excavar.MODID)
public class EventListener {

    public static Map<UUID, List<ItemEntity>> ITEMS_FOR_PLAYER = Maps.newHashMap();

    @SubscribeEvent
    public static void onBreakBlock(BlockEvent.BreakEvent event) {
        if (event.getPlayer() instanceof ServerPlayer player) {
            PlayerHandler playerHandler = Excavar.getPlayerHandler();
            UUID playerId = player.getGameProfile().id();
            if (playerHandler.canDig(player)) {
                BlockState state = event.getState();
                if (!ShapeUtil.miningAllowed(state) || !ListHandler.isToolAllowed(player.getMainHandItem())) {
                    return;
                }

                ServerLevel level = player.level();
                if (NeoForge.EVENT_BUS.post(new DiggingEvent.Pre(level, player, Lists.newArrayList(), state.getBlock())).isCanceled()) {
                    return;
                }

                Direction side = ((BlockHitResult) player.pick(20, 0, false)).getDirection();

                Identifier shapeId = playerHandler.getShapeId(playerId);
                if (!ConfigHandler.allowShapeSelection.get() || Shapes.SHAPELESS.equals(shapeId)) {
                    shapeId = ShapeUtil.getShapeId(state.getBlock());
                }

                Excavador excavador = new Excavador(shapeId, event.getPos(), level, player, side, state);
                excavador.findBlocks();

                if (NeoForge.EVENT_BUS.post(new DiggingEvent.FoundPositions(level, player, excavador.getBlocksToMine(), state.getBlock())).isCanceled()) {
                    playerHandler.stopDigging(playerId);
                    return;
                }

                playerHandler.startDigging(playerId);
                excavador.mine(event.getPlayer().getMainHandItem());
                playerHandler.stopDigging(playerId);

                if (ITEMS_FOR_PLAYER.containsKey(playerId)) {
                    ITEMS_FOR_PLAYER.get(playerId).forEach(e -> {
                        e.setPos(event.getPos().getX(), event.getPos().getY(), event.getPos().getZ());
                        level.addFreshEntity(e);
                    });
                    ITEMS_FOR_PLAYER.remove(playerId);
                }

                NeoForge.EVENT_BUS.post(new DiggingEvent.Post(level, player, excavador.getBlocksToMine(), state.getBlock()));
            }
        }
    }

    @SubscribeEvent
    public static void captureDrops(BlockDropsEvent event) {
        if (!ConfigHandler.collectDrops.get()) {
            return;
        }

        if (event.isCanceled()) {
            return;
        }

        if (event.getBreaker() instanceof ServerPlayer player && Excavar.getPlayerHandler().isDigging(player.getGameProfile().id())) {
            event.setCanceled(true);
            ITEMS_FOR_PLAYER.computeIfAbsent(player.getGameProfile().id(), id -> new ArrayList<>()).addAll(event.getDrops());
        }
    }

    @SubscribeEvent
    public static void register(RegisterRenderPipelinesEvent event) {
        event.registerPipeline(HiddenRenderTypes.HIDDEN_RENDER_PIPELINE);
    }
}
